@@ -3,15 +3,15 @@ package cmd
 import (
 	"errors"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"os"
 	"path/filepath"
 	"time"
 
-	"github.com/mickael-menu/zk/internal/cli"
-	"github.com/mickael-menu/zk/internal/core"
-	dateutil "github.com/mickael-menu/zk/internal/util/date"
-	"github.com/mickael-menu/zk/internal/util/opt"
+	"github.com/zk-org/zk/internal/cli"
+	"github.com/zk-org/zk/internal/core"
+	dateutil "github.com/zk-org/zk/internal/util/date"
+	"github.com/zk-org/zk/internal/util/opt"
 )
 
 // New adds a new note to the notebook.
@@ -36,7 +36,7 @@ func (cmd *New) Run(container *cli.Container) error {
 
 	var content []byte
 	if cmd.Interactive {
-		content, err = ioutil.ReadAll(os.Stdin)
+		content, err = io.ReadAll(os.Stdin)
 		if err != nil {
 			return err
 		}
