@@ -50,8 +50,9 @@ func TestParseDefaultConfig(t *testing.T) {
 		},
 		LSP: LSPConfig{
 			Diagnostics: LSPDiagnosticConfig{
-				WikiTitle: LSPDiagnosticNone,
-				DeadLink:  LSPDiagnosticError,
+				WikiTitle:       LSPDiagnosticNone,
+				DeadLink:        LSPDiagnosticError,
+				MissingBacklink: MissingBacklinkConfig{},
 			},
 		},
 		Filters: make(map[string]string),
@@ -256,8 +257,9 @@ func TestParseComplete(t *testing.T) {
 				UseAdditionalTextEdits: opt.True,
 			},
 			Diagnostics: LSPDiagnosticConfig{
-				WikiTitle: LSPDiagnosticHint,
-				DeadLink:  LSPDiagnosticNone,
+				WikiTitle:       LSPDiagnosticHint,
+				DeadLink:        LSPDiagnosticNone,
+				MissingBacklink: MissingBacklinkConfig{},
 			},
 		},
 		Filters: map[string]string{
@@ -432,8 +434,9 @@ func TestParseMergesGroupConfig(t *testing.T) {
 				},
 			},
 			Diagnostics: LSPDiagnosticConfig{
-				WikiTitle: LSPDiagnosticNone,
-				DeadLink:  LSPDiagnosticError,
+				WikiTitle:       LSPDiagnosticNone,
+				DeadLink:        LSPDiagnosticError,
+				MissingBacklink: MissingBacklinkConfig{},
 			},
 		},
 		Filters: make(map[string]string),
@@ -542,11 +545,13 @@ func TestParseLSPDiagnosticsSeverity(t *testing.T) {
 			[lsp.diagnostics]
 			wiki-title = "%s"
 			dead-link = "%s"
-		`, value, value)
+			self-link = "%s"
+		`, value, value, value)
 		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
 		assert.Nil(t, err)
 		assert.Equal(t, conf.LSP.Diagnostics.WikiTitle, expected)
 		assert.Equal(t, conf.LSP.Diagnostics.DeadLink, expected)
+		assert.Equal(t, conf.LSP.Diagnostics.SelfLink, expected)
 	}
 
 	test("", LSPDiagnosticNone)
@@ -564,6 +569,40 @@ func TestParseLSPDiagnosticsSeverity(t *testing.T) {
 	assert.Err(t, err, "foobar: unknown LSP diagnostic severity - may be none, hint, info, warning or error")
 }
 
+func TestParseMissingBacklinkConfig(t *testing.T) {
+	test := func(level string, position string, expectedLevel LSPDiagnosticSeverity, expectedPosition LSPDiagnosticPosition) {
+		toml := fmt.Sprintf(`
+			[lsp.diagnostics]
+			missing-backlink = { level = "%s", position = "%s" }
+		`, level, position)
+		conf, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
+		assert.Nil(t, err)
+		assert.Equal(t, conf.LSP.Diagnostics.MissingBacklink.Level, expectedLevel)
+		assert.Equal(t, conf.LSP.Diagnostics.MissingBacklink.Position, expectedPosition)
+	}
+
+	test("warning", "top", LSPDiagnosticWarning, LSPDiagnosticPositionTop)
+	test("error", "bottom", LSPDiagnosticError, LSPDiagnosticPositionBottom)
+	test("hint", "last-section", LSPDiagnosticHint, LSPDiagnosticPositionLastSection)
+	test("info", "top", LSPDiagnosticInfo, LSPDiagnosticPositionTop)
+
+	// Test invalid level.
+	toml := `
+		[lsp.diagnostics]
+		missing-backlink = { level = "invalid", position = "top" }
+	`
+	_, err := ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
+	assert.Err(t, err, "invalid: unknown LSP diagnostic severity - may be none, hint, info, warning or error")
+
+	// Test invalid position.
+	toml = `
+		[lsp.diagnostics]
+		missing-backlink = { level = "warning", position = "invalid" }
+	`
+	_, err = ParseConfig([]byte(toml), ".zk/config.toml", NewDefaultConfig(), false)
+	assert.Err(t, err, "invalid: unknown LSP diagnostic position - may be top, bottom, or last-section")
+}
+
 func TestGroupConfigExcludeGlobs(t *testing.T) {
 	// empty globs
 	config := GroupConfig{
